<?php

namespace Drupal\diba_starterkit\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\diba_starterkit\Services\StarterkitManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Diba Starterkit apply settings form.
 */
class ApplySettings extends FormBase {

  /**
   * {@inheritdoc}
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * {@inheritdoc}
   *
   * @var \Drupal\diba_starterkit\Services\StarterkitManager
   */
  protected $starterkitManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    MessengerInterface $messenger,
    StarterkitManager $starterkitManager
  ) {
    $this->messenger = $messenger;
    $this->starterkitManager = $starterkitManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('messenger'),
      $container->get('diba_starterkit.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'diba_starterkit_apply_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['help'] = [
      '#markup' => $this->t('If you click "Apply" this will override current configuration with Diba Starterkit default settings:'),
      '#prefix' => '<p>',
      '#suffix' => '</p>',
    ];
    $form['files'] = [
      '#markup' => '<li>' . implode('</li><li>', array_keys($this->starterkitManager->getConfigFiles())) . '</li>',
      '#prefix' => '<ul>',
      '#suffix' => '</ul>',
    ];
    $form['kit'] = [
      '#type' => 'select',
      '#title' => $this->t('Kit'),
      '#options' => [
        'basic' => $this->t('basic'),
        'standard' => $this->t('standard'),
      ],
      '#default_value' => 'basic',
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Apply'),
      '#button_type' => 'primary',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $kit = $form_state->getValue('kit');
    if ($result = $this->starterkitManager->apply($kit)) {

      $this->messenger->addMessage($this->t('Kit %kit applied successfully.', ['%kit' => $kit]));

      if (!empty($result['imported'])) {
        $this->messenger->addWarning($this->t('Configurations overrided: %imported.', [
          '%imported' => implode(', ', $result['imported']),
        ]));
      }
      else {
        $this->messenger->addError($this->t('Nothing imported.'));
      }

      if (!empty($result['uninstalled'])) {
        $this->messenger->addWarning($this->t('Modules uninstalled: %modules.', [
          '%modules' => implode(', ', $result['uninstalled']),
        ]));
      }
      if (!empty($result['installed'])) {
        $this->messenger->addWarning($this->t('Modules installed: %modules.', [
          '%modules' => implode(', ', $result['installed']),
        ]));
      }
    }
    else {
      $this->messenger->addError($this->t('Nothing imported.'));
    }
  }

}
